DataSet
=======

.. currentmodule:: pykeen.datasets.base

.. autoclass:: DataSet
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~DataSet.entity_to_id
      ~DataSet.factories
      ~DataSet.num_entities
      ~DataSet.num_relations
      ~DataSet.relation_to_id

   .. rubric:: Methods Summary

   .. autosummary::

      ~DataSet.summarize
      ~DataSet.summary_str

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_to_id
   .. autoattribute:: factories
   .. autoattribute:: num_entities
   .. autoattribute:: num_relations
   .. autoattribute:: relation_to_id

   .. rubric:: Methods Documentation

   .. automethod:: summarize
   .. automethod:: summary_str
